==> naifjs-0.41.2.tgz: package/lib/messaging/validateResponseData.js <==
const { isString } = require('./isString')
const { isObject } = require('./isObject')


/**
 * validate request API data object  
 *
 * @param {String} userid
 * @param {string} data
 *
 * valid example
 *   validateResponseData('user utterance') ->  { text: 'user utterance', speech: false }
 *
 * or
 *
 * @param {String} userid
 * @param {Object}  data 
 *
 * valid examples:
 *   
 *   validateResponseData({text: 'user utterance'}) 
 *   // ->  { text: 'user utterance', speech: false }
 *   
 *   validateResponseData({text: 'user utterance' speech: 'user utternace'}) 
 *   //->  { text: 'user utterance', speech: true }
 *
 * @return {Object} valid request data object
 *
 */
function validateResponseData(data) {
  
  // data is an object
  if ( isObject(data) ) {

    // text attribute is mandatory
    if (data.text) {

      // speech attribute is optional/calculated
      if (data.speech) 
        return data 
      else
        return { text: data.text, speech: false }
        
    }  
    else 
      console.error(`ERROR: request data ${JSON.stringify(data)}. Missing "text" attribute`)
  }  

  // data is a string
  else if ( isString(data) ) {
    return { text: data, speech: false }
  }

  else {
    // data is not a valid object
    console.error(`ERROR: request data ${JSON.stringify(data)} is an invalid object`)
  } 

  return null
}


// test
if (require.main === module) {

  let data 

  data = { speech: true }

  console.log(1, data)
  console.log( validateResponseData(data) )
  console.log()

  data = { alfa: 'alfa' } 

  console.log(2, data)
  console.log( validateResponseData(data) )
  console.log()

  data = 'this is an utterance'

  console.log(3, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence'}

  console.log(4, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence', speech: true}

  console.log(5, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence', speech: true, caption: true, sentenceTokenize: false}

  console.log(6, data)
  console.log( validateResponseData(data) )
  console.log()
}  


module.exports = { validateResponseData }

==> naifjs-0.41.4.tgz: package/lib/messaging/validateResponseData.js <==
const { isString } = require('./isString')
const { isObject } = require('./isObject')


/**
 * validate response API data object  
 *
 * @param {String} data
 *
 * valid example
 *   validateResponseData('user utterance') 
 *   ->  { text: 'user utterance', speech: false }
 *
 * or
 *
 * @param {Object} data 
 *
 * valid examples:
 *   
 *   validateResponseData({text: 'user utterance'}) 
 *   ->  { text: 'user utterance', speech: false }
 *   
 *   validateResponseData({text: 'user utterance' speech: 'user utternace'}) 
 *   ->  { text: 'user utterance', speech: true }
 *
 * @return {Object} valid response data object
 *
 */
function validateResponseData(data) {
  
  // data is an object
  if ( isObject(data) ) {

    // text attribute is mandatory
    if (data.text) {

      // speech attribute is optional/calculated
      if (data.speech) 
        return data 
      else
        return { text: data.text, speech: false }
        
    }  
    else 
      console.error(`ERROR: request data ${JSON.stringify(data)}. Missing "text" attribute`)
  }  

  // data is a string
  else if ( isString(data) ) {
    return { text: data, speech: false }
  }

  else {
    // data is not a valid object
    console.error(`ERROR: request data ${JSON.stringify(data)} is an invalid object`)
  } 

  return null
}


// test
if (require.main === module) {

  let data 

  data = { speech: true }

  console.log(1, data)
  console.log( validateResponseData(data) )
  console.log()

  data = { alfa: 'alfa' } 

  console.log(2, data)
  console.log( validateResponseData(data) )
  console.log()

  data = 'this is an utterance'

  console.log(3, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence'}

  console.log(4, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence', speech: true}

  console.log(5, data)
  console.log( validateResponseData(data) )
  console.log()

  data = {text: 'this is a valid sentence', speech: true, caption: true, sentenceTokenize: false}

  console.log(6, data)
  console.log( validateResponseData(data) )
  console.log()
}  


module.exports = { validateResponseData }
